@@ -8,8 +8,8 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/helmfile/vals"
 	"github.com/stretchr/testify/require"
-	"github.com/variantdev/vals"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
@@ -435,23 +435,23 @@ func TestTemplate_CyclicInheritance(t *testing.T) {
 templates:
   a:
     inherit:
-      template: b
+    - template: b
     values:
     - a.yaml
   b:
     inherit:
-      template: c
+    - template: c
     values:
     - b.yaml
   c:
     inherit:
-      template: a
+    - template: a
     values:
     - c.yaml
 releases:
 - name: app1
   inherit:
-    template: a
+  - template: a
   chart: incubator/raw
 `,
 			}
