@@ -16,7 +16,8 @@ type ApplyOptions struct {
 	Output string
 	// DetailedExitcode is true if the exit code should be 2 instead of 0 if there were changes detected and the changes were synced successfully
 	DetailedExitcode bool
-
+	// StripTrailingCR is true if trailing carriage returns should be stripped during diffing
+	StripTrailingCR bool
 	// TODO: Remove this function once Helmfile v0.x
 	// DEPRECATED: Use skip-cleanup instead
 	RetainValuesFiles bool
@@ -55,6 +56,8 @@ type ApplyOptions struct {
 	ResetValues bool
 	// Propagate '--post-renderer' to helmv3 template and helm install
 	PostRenderer string
+	// Cascade '--cascade' to helmv3 delete, available values: background, foreground, or orphan, default: background
+	Cascade string
 }
 
 // NewApply creates a new Apply
@@ -96,6 +99,11 @@ func (a *ApplyImpl) DetailedExitcode() bool {
 	return a.ApplyOptions.DetailedExitcode
 }
 
+// StripTrailingCR is true if trailing carriage returns should be stripped during diffing
+func (a *ApplyImpl) StripTrailingCR() bool {
+	return a.ApplyOptions.StripTrailingCR
+}
+
 // DiffOutput returns the diff output.
 func (a *ApplyImpl) DiffOutput() string {
 	return a.ApplyOptions.Output
@@ -206,3 +214,8 @@ func (a *ApplyImpl) ResetValues() bool {
 func (a *ApplyImpl) PostRenderer() string {
 	return a.ApplyOptions.PostRenderer
 }
+
+// Cascade returns cascade flag
+func (a *ApplyImpl) Cascade() string {
+	return a.ApplyOptions.Cascade
+}
