@@ -22,20 +22,20 @@ const (
 )
 
 type StateLoadError struct {
-	msg   string
+	Msg   string
 	Cause error
 }
 
 func (e *StateLoadError) Error() string {
-	return fmt.Sprintf("%s: %v", e.msg, e.Cause)
+	return fmt.Sprintf("%s: %v", e.Msg, e.Cause)
 }
 
 type UndefinedEnvError struct {
-	msg string
+	Env string
 }
 
 func (e *UndefinedEnvError) Error() string {
-	return e.msg
+	return fmt.Sprintf("environment \"%s\" is not defined", e.Env)
 }
 
 type StateCreator struct {
@@ -138,7 +138,7 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 }
 
 // LoadEnvValues loads environment values files relative to the `baseDir`
-func (c *StateCreator) LoadEnvValues(target *HelmState, env string, ctxEnv, overrode *environment.Environment, failOnMissingEnv bool) (*HelmState, error) {
+func (c *StateCreator) LoadEnvValues(target *HelmState, env string, failOnMissingEnv bool, ctxEnv, overrode *environment.Environment) (*HelmState, error) {
 	state := *target
 
 	e, err := c.loadEnvValues(&state, env, failOnMissingEnv, ctxEnv, overrode)
@@ -162,7 +162,7 @@ func (c *StateCreator) LoadEnvValues(target *HelmState, env string, ctxEnv, over
 
 // Parses YAML into HelmState, while loading environment values files relative to the `baseDir`
 // evaluateBases=true means that this is NOT a base helmfile
-func (c *StateCreator) ParseAndLoad(content []byte, baseDir, file string, envName string, evaluateBases bool, envValues, overrode *environment.Environment) (*HelmState, error) {
+func (c *StateCreator) ParseAndLoad(content []byte, baseDir, file string, envName string, failOnMissingEnv, evaluateBases bool, envValues, overrode *environment.Environment) (*HelmState, error) {
 	state, err := c.Parse(content, baseDir, file)
 	if err != nil {
 		return nil, err
@@ -179,7 +179,7 @@ func (c *StateCreator) ParseAndLoad(content []byte, baseDir, file string, envNam
 		}
 	}
 
-	state, err = c.LoadEnvValues(state, envName, envValues, overrode, evaluateBases)
+	state, err = c.LoadEnvValues(state, envName, failOnMissingEnv, envValues, overrode)
 	if err != nil {
 		return nil, err
 	}
@@ -222,7 +222,7 @@ func (c *StateCreator) loadBases(envValues, overrodeEnv *environment.Environment
 
 // nolint: unparam
 func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEnv bool, ctxEnv, overrode *environment.Environment) (*environment.Environment, error) {
-	envVals := map[string]interface{}{}
+	envVals := map[string]any{}
 	envSpec, ok := st.Environments[name]
 	if ok {
 		var err error
@@ -249,7 +249,7 @@ func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEn
 			}
 		}
 	} else if ctxEnv == nil && name != DefaultEnv && failOnMissingEnv {
-		return nil, &UndefinedEnvError{msg: fmt.Sprintf("environment \"%s\" is not defined", name)}
+		return nil, &UndefinedEnvError{Env: name}
 	}
 
 	newEnv := &environment.Environment{Name: name, Values: envVals, KubeContext: envSpec.KubeContext}
@@ -277,7 +277,7 @@ func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEn
 	return newEnv, nil
 }
 
-func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles []string, envVals map[string]interface{}) error {
+func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles []string, envVals map[string]any) error {
 	var errs []error
 
 	helm := c.getHelm(st)
@@ -286,7 +286,7 @@ func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles
 
 	type secretResult struct {
 		id     int
-		result map[string]interface{}
+		result map[string]any
 		err    error
 		path   string
 	}
@@ -309,8 +309,7 @@ func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles
 		func(id int) {
 			for secret := range secrets {
 				release := &ReleaseSpec{}
-				flags := st.appendConnectionFlags([]string{}, release)
-				decFile, err := helm.DecryptSecret(st.createHelmContext(release, 0), secret.path, flags...)
+				decFile, err := helm.DecryptSecret(st.createHelmContext(release, 0), secret.path)
 				if err != nil {
 					results <- secretResult{secret.id, nil, err, secret.path}
 					continue
@@ -328,13 +327,13 @@ func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles
 					results <- secretResult{secret.id, nil, fmt.Errorf("failed to load environment secrets file \"%s\": %v", secret.path, err), secret.path}
 					continue
 				}
-				m := map[string]interface{}{}
+				m := map[string]any{}
 				if err := yaml.Unmarshal(bytes, &m); err != nil {
 					results <- secretResult{secret.id, nil, fmt.Errorf("failed to load environment secrets file \"%s\": %v", secret.path, err), secret.path}
 					continue
 				}
 				// All the nested map key should be string. Otherwise we get strange errors due to that
-				// mergo or reflect is unable to merge map[interface{}]interface{} with map[string]interface{} or vice versa.
+				// mergo or reflect is unable to merge map[any]any with map[string]any or vice versa.
 				// See https://github.com/roboll/helmfile/issues/677
 				vals, err := maputil.CastKeysToStrings(m)
 				if err != nil {
@@ -374,10 +373,10 @@ func (c *StateCreator) scatterGatherEnvSecretFiles(st *HelmState, envSecretFiles
 	return nil
 }
 
-func (st *HelmState) loadValuesEntries(missingFileHandler *string, entries []interface{}, remote *remote.Remote, ctxEnv *environment.Environment, envName string) (map[string]interface{}, error) {
-	var envVals map[string]interface{}
+func (st *HelmState) loadValuesEntries(missingFileHandler *string, entries []any, remote *remote.Remote, ctxEnv *environment.Environment, envName string) (map[string]any, error) {
+	var envVals map[string]any
 
-	valuesEntries := append([]interface{}{}, entries...)
+	valuesEntries := append([]any{}, entries...)
 	ld := NewEnvironmentValuesLoader(st.storage(), st.fs, st.logger, remote)
 	var err error
 	envVals, err = ld.LoadEnvironmentValues(missingFileHandler, valuesEntries, ctxEnv, envName)
