@@ -50,7 +50,7 @@ func (helm *noCallHelmExec) ChartPull(chart string, path string, flags ...string
 	helm.doPanic()
 	return nil
 }
-func (helm *noCallHelmExec) ChartExport(chart string, path string, flags ...string) error {
+func (helm *noCallHelmExec) ChartExport(chart string, path string) error {
 	helm.doPanic()
 	return nil
 }
@@ -85,7 +85,7 @@ func (helm *noCallHelmExec) UpdateRepo() error {
 	helm.doPanic()
 	return nil
 }
-func (helm *noCallHelmExec) RegistryLogin(name string, username string, password string) error {
+func (helm *noCallHelmExec) RegistryLogin(name, username, password, caFile, certFile, keyFile string, skipTLSVerify bool) error {
 	helm.doPanic()
 	return nil
 }
